#
# spec file for package reco
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           reco
Version:        3.2.1
Release:        1.10
Summary:        Audio Recording App
License:        GPL-3.0-or-later
Group:          Productivity/Multimedia/Sound/Utilities
URL:            https://github.com/ryonakano/reco
Source:         https://github.com/ryonakano/reco/archive/refs/tags/%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  fdupes
BuildRequires:  hicolor-icon-theme
BuildRequires:  libxml2-tools
BuildRequires:  meson >= 0.49.0
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  vala
BuildRequires:  pkgconfig(granite) >= 5.2.3
BuildRequires:  pkgconfig(gstreamer-1.0)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(libhandy-1)
BuildRequires:  pkgconfig(libpulse)
Recommends:     %{name}-lang

%description
An audio recording app designed for elementary OS.

%lang_package

%prep
%setup -q

# Switch to bugs.opensuse.org
find -name \*.xml* -exec \
sed -i '/bugtracker/s|>[^>]*<|>https://bugs.opensuse.org<|' {} +

%build
%meson
%meson_build

%install
%meson_install
%suse_update_desktop_file -r com.github.ryonakano.reco GTK Utility AudioVideo
%find_lang com.github.ryonakano.reco %{name}.lang
%fdupes %{buildroot}/%{_datadir}

%files
%license LICENSE
%doc README.md
%{_bindir}/com.github.ryonakano.reco
%{_datadir}/applications/com.github.ryonakano.reco.desktop
%{_datadir}/glib-2.0/schemas/com.github.ryonakano.reco.gschema.xml
%{_datadir}/icons/hicolor/*/apps/com.github.ryonakano.reco.??g
%{_datadir}/icons/hicolor/*/apps/record-completed-symbolic.??g
%{_datadir}/metainfo/com.github.ryonakano.reco.appdata.xml

%files lang -f %{name}.lang

%changelog
* Sun Feb 20 2022 Alexei Podvalsky <avvissu@yandex.by>
- Update to 3.2.1:
  * Reco is now available on Flathub too!
  * Update Spanish translation (thanks to @Eldhrimer)
  * Update Italian translation (thanks to @albanobattistella)
  * Let's celebrate the new year with the issue from the ancient
    fixed!
  * Replace AAC option with ALAC to prevent strange stereo files
    being generated
  * The release for celebrating the 3rd anniversary of the app!
  * Add new style switcher
  * Update Dutch translation (thanks to @Vistaus)
  * Update Portuguese translation (thanks to @hugok79)
  * Update Japanese translation
* Fri Oct  8 2021 Alexei Podvalsky <avvissu@yandex.by>
- Update to 3.0.1:
  * Use the user cache folder instead of the system temporary
    folder to save temporary recording files
  * Fix wrong OARS data
- Translation updates:
  * Update Italian translation (thanks to @albanobattistella)
  * Update Japanese translation
  * Publish the app to the new AppCenter on elementary OS 6 with
    the Flatpak manifest
  * A completely rewrited and improved method to detect recording
    sources
  * Redesign: Separate Delay and Duration settings from Recording
    section as Timer section and put it under Recording section
  * Make sure to show a dialog for any errors in recording
  * Code refactoring
  * Add Brazilian Portuguese translation (thanks to
    @mathessaricci)
  * Update Portuguese translation (thanks to @hugok79)
  * Update Spanish translation (thanks to @Eldhrimer)
* Thu Sep  9 2021 Alexei Podvalsky <avvissu@yandex.by>
- Update to 2.4.6:
  * Update Portuguese translation (thanks to @hugok79)
  * Update Spanish translation and add Catalan translation (thanks to @fitojb)
  * Update Japanese translation
* Fri May  7 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 2.4.5
  * Update Dutch, Japanese and Turkish translation
  * Add Italian and Portuguese translation
  * MainWindow: Readable copy for dialog messages
  * MainWindow: Add window title for the new Gala feature that
    shows windows titles in Multitasking view
  * Inhibit sleeping while recording
  * Make sure GSettings key "length" and "delay" take only natural numbers
  * Follow API change of Gtk.FileChooser in GTK 4
  * Fix temporary recordings are not deleted on error
  * Fix some microphones are not recognized
* Thu Jul 16 2020 Alexei Podvalsky <avvissu@yandex.by>
- Update to 2.4.0:
  * Update screenshots
  * Recorder: Always record in stereo (#68)
  * Fix the oops that I should cut, not copy
  * Recorder: Enums in the top of files
  * Allow setting per-app dark style preference (#67)
  * README: Requires gstreamer1.0-libav as a runtime dependency
  * Consistent naming in favor of SourceDevice.SYSTEM
  * Recorder Cast as a new Enum instead of a row int (#65)
  * Fix comment notation
  * Add execuse permission to post_install.py
  * Add 'Gettext updates' GitHub Actions
  * Fix elementary OS-wide dark preference isn't applied
  * Respect an elementary OS-wide dark preference (#62)
  * Add linter to CI
* Sat Mar 28 2020 Alexei Podvalsky <avvissu@yandex.by>
- Update to 2.3.2:
  * Set Node.js version to 10.17.0 to fix CI
  * Update copyright headers
  * WelcomeView: Get delay value from GLib.settings intead of the
    widget
* Mon Dec  9 2019 Alexei Podvalsky <avvissu@yandex.by>
- Update to 2.3.1:
  * Remove localized screenshots
  * Recorder: Signals at the top
  * Use GLib.Settings.bind (#55)
  * Add Polish to LINGUAS (#52)
  * Update POTFILES
  * Downgrade Node.js to fix builds on Travis CI (#50)
* Mon Nov  4 2019 Alexei Podvalsky <avvissu@yandex.by>
- Update to 2.3.0:
  * Update screenshots
  * Support three source selections (#48)
  * Recorder: Add missing null check for the encoder
  * Fix the count is increased even if users click the pause
    button
  * Fix the behavior of the countdown timer when
    pausing/canceling it (#46)
  * Emphasize 'at the same time' in the app description
  * Remove unnecessary field code that marks files handleable
  * Recorder: Use more readable variable names
  * Unify to use verbal noun: save -> saving
  * Fix completely reversed expression
  * More tantalizing app description
  * Change the expression of recording system sound option
  * Small recorder refactoring (#43)
  * Correct spell: Gstreamer -> GStreamer
  * Support recording both sounds from mic and from PC (#42)
* Tue Oct  1 2019 Alexei Podvalsky <avvissu@yandex.by>
- Update to 2.2.1:
  * Add Spanish screenshots
  * DRY in selecting encoder and fix long lines
* Mon Sep  9 2019 Alexei Podvalsky <avvissu@yandex.by>
- Update to 2.2.0:
  * MainWindow: Remove a redundant comment
  * MainWindow: Prevents position changes from being spammed
  * Recorder refactoring (#38)
  * Fix forgetting to remove the unnecessary string for debug
  * Show successful mark when a recording is saved correctly
  * Resume the pause icon on canceling recording
  * MainWindow: Remove the unused 'app' property
  * RecordView: Remove the unused 'app' property
  * Omit the instruction that build the app to update .po files
  * Revert "Add name-domain to .travis.yml"
  * Add name-domain to .travis.yml
  * Use more efficient way to get/set window positions
* Wed Aug  7 2019 Alexei Podvalsky <avvissu@yandex.by>
- Update to 2.1.0:
  * Update screenshots
  * Fix the app freezes on closing an error dialog
  * Save recordings when the app window is destroyed (#35)
  * Use GLib methods for debug instead of printf
  * Allow to cancel/pause countdown before recording (#36)
  * Lessen scope if possible
  * Use 'meson.project_name()' instead of hardcoding
  * Use Granite constants for text styles
  * Avoid emulating click signals
* Mon Jun  3 2019 Alexei Podvalsky <avvissu@yandex.by>
- Update to 2.0.0:
  * See you Transifex
  * Fix the timer does not stop in accordance with the recording
  * Allow to record system sound (#31)
  * Clarify how to request a language
  * Fix wrong alignment of buttons
  * Fix a typo in xml element name
  * Reco now uses transifex for localization
* Mon Apr 15 2019 Alexei Podvalsky <avvissu@yandex.by>
- Update to 1.1.2:
  * Reflect RADME's changes to appdata
  * Grammatically fixes in README.md (#30)
  * Use hyphen instead of underbar for lang element
* Mon Apr  1 2019 Alexei Podvalsky <avvissu@yandex.by>
- Update to 1.1.1:
  * Use upper case for WAV
  * Small fixes for notation, spacing, naming, and so on
  * Fix temporary recording files remain when quit the app while
    recording
  * Provide localized screenshots to AppCenter
* Mon Mar 11 2019 Alexei Podvalsky <avvissu@yandex.by>
- Update to 1.1.0:
  * Revert "Another experiment to check what about adding type
    attribute"
  * Another experiment to check what about adding type attribute
  * Attempt to fix CI by removing localized screenshots
  * Attempt to fix CI by changing the location of caption line
  * Fix wrong word: installed -> finished
  * Provide more (and localized) screenshots on AppCenter
  * Show error details using show_error_details method
  * Allow to cancel/pause recording (#24)
  * Notify success of recording with a check mark (#23)
  * Use switch/if instead of else/if
  * Fix the name of "Recordings" folder is not created in system
    language (Fixes #25)
  * Set required granite version
  * Add a shortcut key to toggle recording
* Mon Feb 25 2019 Alexei Podvalsky <avvissu@yandex.by>
- Update to 1.0.3:
  * Fix the app isn't listed in the "Sound & Video" category in
    Applications Menu
  * Use FileChooserNative
  * Do not have an extra file for warning_dialog
  * Grammar fix in a comment
  * Show a confirmation dialog when trying to quit the app if a
    recording is in progress
  * Coding Improvement
  * Fix scope
  * Fix destination is not created when users delete it after
    first launch
  * Update copyright
  * Fix notation disunifications
  * Access to GLib.Settings instead of properties
* Mon Jan 21 2019 Alexei Podvalsky <avvissu@yandex.by>
- Update to 1.0.2:
  * Add an inclusive guidline and remove po/README.md
  * Sort language codes in LINGUAS alphabetically
  * Fix remaining_time_label is shown even if record_length is 0
    once it is set
  * Fix a GLib error that no source ID found to remove is shown
  * Update the screenshot
  * Save settings on the app startup (Fixes #17)
  * Support both do-not-ask-where-to-save flow and
    ask-where-to-save flow (#16)
  * Update README.md and the screenshot
* Sat Dec 29 2018 Alexei Podvalsky <avvissu@yandex.by>
- Update to 1.0.1:
  * Fix a typo in the release note
  * Allow to bring timestanp anywhere in the filename
  * Add keywords to the .desktop file
  * Allow to set recording rength (#13)
  * Separate full_path from filename
  * Add release notes to appdata file
  * Fix a wrong word: Complete -> Compile
* Wed Dec 12 2018 Alexei Podvalsky <avvissu@yandex.by>
- Initial package
